==> mailjet-client-4.1.1-sources.jar: com/mailjet/client/resource/Campaignstatistics.java <==

/*
 * This is a generated class.
 */

package com.mailjet.client.resource;

import com.mailjet.client.Resource;

/**
 *
 * @author Guillaume Badi
 */
public class Campaignstatistics {

    public static Resource resource = new Resource("campaignstatistics", "");

	public static String AXTESTING = "AXTesting";
	public static String BLOCKEDCOUNT = "BlockedCount";
	public static String BOUNCEDCOUNT = "BouncedCount";
	public static String CAMPAIGN = "Campaign";
	public static String CAMPAIGNISSTARRED = "CampaignIsStarred";
	public static String CAMPAIGNSENDSTARTAT = "CampaignSendStartAt";
	public static String CAMPAIGNSUBJECT = "CampaignSubject";
	public static String CLICKEDCOUNT = "ClickedCount";
	public static String CONTACTLISTNAME = "ContactListName";
	public static String DELIVEREDCOUNT = "DeliveredCount";
	public static String LASTACTIVITYAT = "LastActivityAt";
	public static String NEWSLETTER = "NewsLetter";
	public static String OPENEDCOUNT = "OpenedCount";
	public static String PROCESSEDCOUNT = "ProcessedCount";
	public static String QUEUEDCOUNT = "QueuedCount";
	public static String SEGMENTNAME = "SegmentName";
	public static String SPAMCOMPLAINTCOUNT = "SpamComplaintCount";
	public static String UNSUBSCRIBEDCOUNT = "UnsubscribedCount";
	public static String BLOCKED = "Blocked";
	public static String BOUNCED = "Bounced";
	public static String CAMPAIGNSTATUS = "CampaignStatus";
	public static String CLICK = "Click";
	public static String CONTACTSLIST = "ContactsList";
	public static String FROMTS = "FromTS";
	public static String FROMTYPE = "FromType";
	public static String GROUPAX = "GroupAX";
	public static String ISDELETED = "IsDeleted";
	public static String ISSTARRED = "IsStarred";
	public static String MAXLASTACTIVITYAT = "MaxLastActivityAt";
	public static String MINLASTACTIVITYAT = "MinLastActivityAt";
	public static String OPEN = "Open";
	public static String QUEUED = "Queued";
	public static String SEGMENTATION = "Segmentation";
	public static String SENDER = "Sender";
	public static String SENT = "Sent";
	public static String SHOWEXTRADATA = "ShowExtraData";
	public static String SPAM = "Spam";
	public static String SUBJECT = "Subject";
	public static String TOTS = "ToTS";
	public static String UNSUBSCRIBED = "Unsubscribed";
	public static String LIMIT = "Limit";
	public static String OFFSET = "Offset";
	public static String COUNTONLY = "CountOnly";

}

==> mailjet-client-4.5.0-sources.jar: com/mailjet/client/resource/Campaignstatistics.java <==

/*
 * This is a generated class.
 */

package com.mailjet.client.resource;

import com.mailjet.client.Resource;

/**
 *
 * @author Guillaume Badi
 */
public class Campaignstatistics {

    public static Resource resource = new Resource("campaignstatistics", "");

	public static String AXTESTING = "AXTesting";
	public static String BLOCKEDCOUNT = "BlockedCount";
	public static String BOUNCEDCOUNT = "BouncedCount";
	public static String CAMPAIGN = "Campaign";
	public static String CAMPAIGNISSTARRED = "CampaignIsStarred";
	public static String CAMPAIGNSENDSTARTAT = "CampaignSendStartAt";
	public static String CAMPAIGNSUBJECT = "CampaignSubject";
	public static String CLICKEDCOUNT = "ClickedCount";
	public static String CONTACTLISTNAME = "ContactListName";
	public static String DELIVEREDCOUNT = "DeliveredCount";
	public static String LASTACTIVITYAT = "LastActivityAt";
	public static String NEWSLETTER = "NewsLetter";
	public static String OPENEDCOUNT = "OpenedCount";
	public static String PROCESSEDCOUNT = "ProcessedCount";
	public static String QUEUEDCOUNT = "QueuedCount";
	public static String SEGMENTNAME = "SegmentName";
	public static String SPAMCOMPLAINTCOUNT = "SpamComplaintCount";
	public static String UNSUBSCRIBEDCOUNT = "UnsubscribedCount";
	public static String BLOCKED = "Blocked";
	public static String BOUNCED = "Bounced";
	public static String CAMPAIGNSTATUS = "CampaignStatus";
	public static String CLICK = "Click";
	public static String CONTACTSLIST = "ContactsList";
	public static String FROMTS = "FromTS";
	public static String FROMTYPE = "FromType";
	public static String GROUPAX = "GroupAX";
	public static String ISDELETED = "IsDeleted";
	public static String ISSTARRED = "IsStarred";
	public static String MAXLASTACTIVITYAT = "MaxLastActivityAt";
	public static String MINLASTACTIVITYAT = "MinLastActivityAt";
	public static String OPEN = "Open";
	public static String QUEUED = "Queued";
	public static String SEGMENTATION = "Segmentation";
	public static String SENDER = "Sender";
	public static String SENT = "Sent";
	public static String SHOWEXTRADATA = "ShowExtraData";
	public static String SPAM = "Spam";
	public static String SUBJECT = "Subject";
	public static String TOTS = "ToTS";
	public static String UNSUBSCRIBED = "Unsubscribed";
	public static String LIMIT = "Limit";
	public static String OFFSET = "Offset";
	public static String COUNTONLY = "CountOnly";
	public static final String SOFTBOUNCEDCOUNT = "SoftbouncedCount";
	public static final String HARDBOUNCEDCOUNT = "HardbouncedCount";
	public static final String DEFERREDCOUNT = "DeferredCount";
	public static final String WORKFLOWEXITEDCOUNT = "WorkflowExitedCount";

}
